@@ -24,7 +24,7 @@ from weibopy.error import WeibopError
 from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from flickcharm import FlickCharm
 import shutil
-import glob
+import fnmatch
 
 
 # Define some constants
@@ -105,14 +105,15 @@ class MaoboApp(QApplication):
         self.osso_c = osso.Context(SH_DBUS_NAME,"0.0.1",False)
         self.osso_rpc = osso.Rpc(self.osso_c)
         self.osso_rpc.set_rpc_callback(SH_DBUS_NAME, SH_DBUS_PATH, SH_DBUS_IFACE, self.send_via_service, self.osso_c)
-
+        
+        
         self.sendersina_service=SenderSina(self.show_notice)
         self.senderqq_service=SenderQQ(self.show_notice)
 
         self.clean_temp_images("/home/user/.sharing/outbox")
         
         Utils.g_orietation=self.get_current_orientation()
-        
+
         if len(self.accounts)==0:
             self.defaultWin.show()
         else:
@@ -123,7 +124,7 @@ class MaoboApp(QApplication):
         print "send_via_service"
         
         if method == SH_SHARE_SIG:
-            print args[0], args[1],args[2], args[3]
+           # print args[0], args[1],args[2], args[3]
 
             dst_file = args[0] + ".jpg"
             shutil.copyfile(args[0], dst_file)  
@@ -133,6 +134,11 @@ class MaoboApp(QApplication):
             if args[1] != "":
                 param["status"] = args[1] + ": "
             param["status"]=param["status"]+args[2]
+
+            if param["status"] == "":
+                param["status"] = "Share image. " + datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+
+            #print param["status"]
             
             if dst_file != None:
                 param["pic"] = dst_file
@@ -156,7 +162,7 @@ class MaoboApp(QApplication):
                     self.show_notice("微博发送中...")
                     sender.start()                        
         else:
-            print "Not support"
+            print "Not support method: " + method
             return
             
     def clean_temp_images(self, outbox_path):
@@ -165,8 +171,9 @@ class MaoboApp(QApplication):
             for path in paths:
                 filePath = os.path.join(outbox_path, path)
                 if os.path.isfile(filePath):
-                    try:
-                        for filePath in glob.glob('*.jpg'):
+                    try:                        
+                        if fnmatch.fnmatch(filePath,'*.jpg'):
+                            print filePath
                             os.remove(filePath)
                     except os.error:
                         continue
